==> contentsquare-3.8.0.tar.gz: ios/Classes/Infrastructure/Proxies/GetStoredConfigProxy.swift <==
/// Allows to get stored config from the state
protocol GetStoredConfigProxy {
    /// Get the stored config from the plugin state
    func getStoredConfig() throws -> [String:Any]
}

/// Factory creator class for [GetStoredConfigProxy].
struct GetStoredConfigProxyFactory {

    /// Creates a new instance of the default implementation of [GetStoredConfigProxy].
    ///
    /// - Parameter featuresState: The `SwiftContentsquarePluginState` used to store the state
    static func makeDefault(featuresState: SwiftContentsquarePluginState = SwiftContentsquarePluginState.shared) -> GetStoredConfigProxy {
        return GetStoredConfigProxyImpl(featuresState: featuresState)
    }
}

/// An implementation of [GetStoredConfigProxy]
class GetStoredConfigProxyImpl: GetStoredConfigProxy {
    
    private let _featuresState: SwiftContentsquarePluginState
    
    /// Creates a new instance of `GetStoredConfigProxyImpl`
    ///
    /// - Parameter featuresState: The `SwiftContentsquarePluginState` used to store the state
    internal init(featuresState: SwiftContentsquarePluginState) {
        self._featuresState = SwiftContentsquarePluginState.shared
    }
    
    func getStoredConfig() throws -> [String : Any] {
        return [
            FlutterFeaturesKey.enableApiErrors.rawValue: _featuresState.getApiErrorsState().value,
            FlutterFeaturesKey.enableSR.rawValue:_featuresState.getSessionReplayState().value,
            FlutterFeaturesKey.containerRecordingId.rawValue:_featuresState.getSessionReplayContainerRecordingId().value,
            FlutterFeaturesKey.enableCrashReporter.rawValue:_featuresState.getCrashReporterState().value,
            FlutterFeaturesKey.featureFlags.rawValue: _featuresState.getFeatureFlagsState().value,
            FlutterFeaturesKey.enableCsInApp.rawValue: _featuresState.getCsInAppState().value
            ]
    }
}

==> contentsquare-3.9.0.tar.gz: ios/Classes/Infrastructure/Proxies/GetStoredConfigProxy.swift <==
/// Allows to get stored config from the state
protocol GetStoredConfigProxy {
    /// Get the stored config from the plugin state
    func getStoredConfig() throws -> [String:Any]
}

/// Factory creator class for [GetStoredConfigProxy].
struct GetStoredConfigProxyFactory {

    /// Creates a new instance of the default implementation of [GetStoredConfigProxy].
    ///
    /// - Parameter featuresState: The `SwiftContentsquarePluginState` used to store the state
    static func makeDefault(featuresState: SwiftContentsquarePluginState = SwiftContentsquarePluginState.shared) -> GetStoredConfigProxy {
        return GetStoredConfigProxyImpl(featuresState: featuresState)
    }
}

/// An implementation of [GetStoredConfigProxy]
class GetStoredConfigProxyImpl: GetStoredConfigProxy {
    
    private let _featuresState: SwiftContentsquarePluginState
    
    /// Creates a new instance of `GetStoredConfigProxyImpl`
    ///
    /// - Parameter featuresState: The `SwiftContentsquarePluginState` used to store the state
    internal init(featuresState: SwiftContentsquarePluginState) {
        self._featuresState = SwiftContentsquarePluginState.shared
    }
    
    func getStoredConfig() throws -> [String : Any] {
        return [
            FlutterFeaturesKey.enableApiErrors.rawValue: _featuresState.getApiErrorsState().value,
            FlutterFeaturesKey.enableSR.rawValue:_featuresState.getSessionReplayState().value,
            FlutterFeaturesKey.containerRecordingId.rawValue:_featuresState.getSessionReplayContainerRecordingId().value,
            FlutterFeaturesKey.enableCrashReporter.rawValue:_featuresState.getCrashReporterState().value,
            FlutterFeaturesKey.featureFlags.rawValue: _featuresState.getFeatureFlagsState().value,
            FlutterFeaturesKey.enableCsInApp.rawValue: _featuresState.getCsInAppState().value,
            FlutterFeaturesKey.appInfo.rawValue: _featuresState.getAppInfoState().value
            ]
    }
}
